@@ -18,9 +18,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /**
@@ -211,8 +209,8 @@ clutter_behaviour_scale_class_init (ClutterBehaviourScaleClass *klass)
    * Since: 0.6
    */
   pspec = g_param_spec_double ("x-scale-start",
-                               "X Start Scale",
-                               "Initial scale on the X axis",
+                               P_("X Start Scale"),
+                               P_("Initial scale on the X axis"),
                                0.0, G_MAXDOUBLE,
                                1.0,
                                CLUTTER_PARAM_READWRITE);
@@ -227,8 +225,8 @@ clutter_behaviour_scale_class_init (ClutterBehaviourScaleClass *klass)
    * Since: 0.6
    */
   pspec = g_param_spec_double ("x-scale-end",
-                               "X End Scale",
-                               "Final scale on the X axis",
+                               P_("X End Scale"),
+                               P_("Final scale on the X axis"),
                                0.0, G_MAXDOUBLE,
                                1.0,
                                CLUTTER_PARAM_READWRITE);
@@ -243,8 +241,8 @@ clutter_behaviour_scale_class_init (ClutterBehaviourScaleClass *klass)
    * Since: 0.6
    */
   pspec = g_param_spec_double ("y-scale-start",
-                               "Y Start Scale",
-                               "Initial scale on the Y axis",
+                               P_("Y Start Scale"),
+                               P_("Initial scale on the Y axis"),
                                0.0, G_MAXDOUBLE,
                                1.0,
                                CLUTTER_PARAM_READWRITE);
@@ -259,8 +257,8 @@ clutter_behaviour_scale_class_init (ClutterBehaviourScaleClass *klass)
    * Since: 0.6
    */
   pspec = g_param_spec_double ("y-scale-end",
-                               "Y End Scale",
-                               "Final scale on the Y axis",
+                               P_("Y End Scale"),
+                               P_("Final scale on the Y axis"),
                                0.0, G_MAXDOUBLE,
                                1.0,
                                CLUTTER_PARAM_READWRITE);
