@@ -39,6 +39,16 @@
  *   alignment policies.</simpara></listitem>
  * </itemizedlist>
  *
+ * <figure id="bin-layout">
+ *   <title>Bin layout</title>
+ *   <para>The image shows a #ClutterBinLayout with three layers:
+ *   a background #ClutterCairoTexture, set to fill on both the X
+ *   and Y axis; a #ClutterTexture, set to center on both the X and
+ *   Y axis; and a #ClutterRectangle, set to %CLUTTER_BIN_ALIGNMENT_END
+ *   on both the X and Y axis.</para>
+ *   <graphic fileref="bin-layout.png" format="PNG"/>
+ * </figure>
+ *
  * <example id="example-clutter-bin-layout">
  *  <title>How to pack actors inside a BinLayout</title>
  *  <para>The following code shows how to build a composite actor with
@@ -241,9 +251,9 @@ clutter_bin_layer_class_init (ClutterBinLayerClass *klass)
   gobject_class->get_property = clutter_bin_layer_get_property;
 
   pspec = g_param_spec_enum ("x-align",
-                             "Horizontal Alignment",
-                             "Horizontal alignment for the actor "
-                             "inside the layer",
+                             P_("Horizontal Alignment"),
+                             P_("Horizontal alignment for the actor "
+                                "inside the layer"),
                              CLUTTER_TYPE_BIN_ALIGNMENT,
                              CLUTTER_BIN_ALIGNMENT_CENTER,
                              CLUTTER_PARAM_READWRITE);
@@ -252,9 +262,9 @@ clutter_bin_layer_class_init (ClutterBinLayerClass *klass)
                                    pspec);
 
   pspec = g_param_spec_enum ("y-align",
-                             "Vertical Alignment",
-                             "Vertical alignment for the actor "
-                             "inside the layer manager",
+                             P_("Vertical Alignment"),
+                             P_("Vertical alignment for the actor "
+                                "inside the layer manager"),
                              CLUTTER_TYPE_BIN_ALIGNMENT,
                              CLUTTER_BIN_ALIGNMENT_CENTER,
                              CLUTTER_PARAM_READWRITE);
@@ -449,6 +459,7 @@ clutter_bin_layout_allocate (ClutterLayoutManager   *manager,
           continue;
         }
 
+      child_width = child_height = 0;
       request = clutter_actor_get_request_mode (child);
       if (request == CLUTTER_REQUEST_HEIGHT_FOR_WIDTH)
         {
@@ -519,6 +530,12 @@ clutter_bin_layout_allocate (ClutterLayoutManager   *manager,
   g_list_free (children);
 }
 
+static GType
+clutter_bin_layout_get_child_meta_type (ClutterLayoutManager *manager)
+{
+  return CLUTTER_TYPE_BIN_LAYER;
+}
+
 static ClutterLayoutMeta *
 clutter_bin_layout_create_child_meta (ClutterLayoutManager *manager,
                                       ClutterContainer     *container,
@@ -542,9 +559,13 @@ clutter_bin_layout_set_container (ClutterLayoutManager *manager,
                                   ClutterContainer     *container)
 {
   ClutterBinLayoutPrivate *priv;
+  ClutterLayoutManagerClass *parent_class;
 
   priv = CLUTTER_BIN_LAYOUT (manager)->priv;
   priv->container = container;
+
+  parent_class = CLUTTER_LAYOUT_MANAGER_CLASS (clutter_bin_layout_parent_class);
+  parent_class->set_container (manager, container);
 }
 
 static void
@@ -619,9 +640,9 @@ clutter_bin_layout_class_init (ClutterBinLayoutClass *klass)
    * Since: 1.2
    */
   pspec = g_param_spec_enum ("x-align",
-                             "Horizontal Alignment",
-                             "Default horizontal alignment for the actors "
-                             "inside the layout manager",
+                             P_("Horizontal Alignment"),
+                             P_("Default horizontal alignment for the actors "
+                                "inside the layout manager"),
                              CLUTTER_TYPE_BIN_ALIGNMENT,
                              CLUTTER_BIN_ALIGNMENT_CENTER,
                              CLUTTER_PARAM_READWRITE);
@@ -636,9 +657,9 @@ clutter_bin_layout_class_init (ClutterBinLayoutClass *klass)
    * Since: 1.2
    */
   pspec = g_param_spec_enum ("y-align",
-                             "Vertical Alignment",
-                             "Default vertical alignment for the actors "
-                             "inside the layout manager",
+                             P_("Vertical Alignment"),
+                             P_("Default vertical alignment for the actors "
+                                "inside the layout manager"),
                              CLUTTER_TYPE_BIN_ALIGNMENT,
                              CLUTTER_BIN_ALIGNMENT_CENTER,
                              CLUTTER_PARAM_READWRITE);
@@ -652,6 +673,8 @@ clutter_bin_layout_class_init (ClutterBinLayoutClass *klass)
     clutter_bin_layout_allocate;
   layout_class->create_child_meta =
     clutter_bin_layout_create_child_meta;
+  layout_class->get_child_meta_type =
+    clutter_bin_layout_get_child_meta_type;
   layout_class->set_container =
     clutter_bin_layout_set_container;
 }
