@@ -9,7 +9,7 @@
  *              Iain Holmes <iain@o-hand.com>
  *              Neil Roberts <neil@linux.intel.com>
  *
- * Copyright (C) 2008  Intel Corporation.
+ * Copyright (C) 2008, 2009, 2010  Intel Corporation.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,9 +22,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /**
@@ -54,6 +52,12 @@
  *   cairo_destroy (cr);
  * ]|
  *
+ * Although a new #cairo_t is created each time you call
+ * clutter_cairo_texture_create() or
+ * clutter_cairo_texture_create_region(), it uses the same
+ * #cairo_surface_t each time. You can call
+ * clutter_cairo_texture_clear() to erase the contents between calls.
+ *
  * <warning><para>Note that you should never use the code above inside the
  * #ClutterActor::paint or #ClutterActor::pick virtual functions or
  * signal handlers because it will lead to performance
@@ -92,7 +96,7 @@ enum
 
 #ifdef CLUTTER_ENABLE_DEBUG
 #define clutter_warn_if_paint_fail(obj)                 G_STMT_START {  \
-  if (CLUTTER_PRIVATE_FLAGS ((obj)) & CLUTTER_ACTOR_IN_PAINT) {         \
+  if (CLUTTER_ACTOR_IN_PAINT (obj)) {                                   \
     g_warning ("%s should not be called during the paint sequence "     \
                "of a ClutterCairoTexture as it will likely cause "      \
                "performance issues.", G_STRFUNC);                       \
@@ -103,6 +107,15 @@ enum
 
 #define CLUTTER_CAIRO_TEXTURE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CLUTTER_TYPE_CAIRO_TEXTURE, ClutterCairoTexturePrivate))
 
+/* Cairo stores the data in native byte order as ARGB but Cogl's pixel
+   formats specify the actual byte order. Therefore we need to use a
+   different format depending on the architecture */
+#if G_BYTE_ORDER == G_LITTLE_ENDIAN
+#define CLUTTER_CAIRO_TEXTURE_PIXEL_FORMAT COGL_PIXEL_FORMAT_BGRA_8888_PRE
+#else
+#define CLUTTER_CAIRO_TEXTURE_PIXEL_FORMAT COGL_PIXEL_FORMAT_ARGB_8888_PRE
+#endif
+
 struct _ClutterCairoTexturePrivate
 {
   cairo_format_t   format;
@@ -223,6 +236,7 @@ static inline void
 clutter_cairo_texture_surface_resize_internal (ClutterCairoTexture *cairo)
 {
   ClutterCairoTexturePrivate *priv = cairo->priv;
+  CoglHandle cogl_texture;
 
   if (priv->cr_surface)
     {
@@ -286,14 +300,15 @@ clutter_cairo_texture_surface_resize_internal (ClutterCairoTexture *cairo)
 			       cairo,
                                clutter_cairo_texture_surface_destroy);
 
-  /* The texture data will be all zeroes so we can use it to create a
-   * blank Cogl texture even though its in a different format
-   */
-  clutter_texture_set_from_rgb_data (CLUTTER_TEXTURE (cairo),
-				     priv->cr_surface_data,
-				     TRUE, priv->width, priv->height,
-				     priv->rowstride,
-				     4, 0, NULL);
+  /* Create a blank Cogl texture */
+  cogl_texture = cogl_texture_new_from_data (priv->width, priv->height,
+                                             COGL_TEXTURE_NONE,
+                                             CLUTTER_CAIRO_TEXTURE_PIXEL_FORMAT,
+                                             COGL_PIXEL_FORMAT_ANY,
+                                             priv->rowstride,
+                                             priv->cr_surface_data);
+  clutter_texture_set_cogl_texture (CLUTTER_TEXTURE (cairo), cogl_texture);
+  cogl_handle_unref (cogl_texture);
 }
 
 static void
@@ -305,8 +320,8 @@ clutter_cairo_texture_notify (GObject    *object,
      that if both the width and height properties are set using a
      single call to g_object_set then the surface will only be resized
      once because the notifications will be frozen in between */
-  if (!strcmp ("surface-width", pspec->name)
-      || !strcmp ("surface-height", pspec->name))
+  if (strcmp ("surface-width", pspec->name) == 0 ||
+      strcmp ("surface-height", pspec->name) == 0)
     {
       ClutterCairoTexture *cairo = CLUTTER_CAIRO_TEXTURE (object);
 
@@ -319,9 +334,9 @@ clutter_cairo_texture_notify (GObject    *object,
 
 static void
 clutter_cairo_texture_get_preferred_width (ClutterActor *actor,
-                                           ClutterUnit   for_height,
-                                           ClutterUnit  *min_width,
-                                           ClutterUnit  *natural_width)
+                                           gfloat        for_height,
+                                           gfloat       *min_width,
+                                           gfloat       *natural_width)
 {
   ClutterCairoTexturePrivate *priv = CLUTTER_CAIRO_TEXTURE (actor)->priv;
 
@@ -329,14 +344,14 @@ clutter_cairo_texture_get_preferred_width (ClutterActor *actor,
     *min_width = 0;
 
   if (natural_width)
-    *natural_width = CLUTTER_UNITS_FROM_DEVICE (priv->width);
+    *natural_width = (gfloat) priv->width;
 }
 
 static void
 clutter_cairo_texture_get_preferred_height (ClutterActor *actor,
-                                            ClutterUnit   for_width,
-                                            ClutterUnit  *min_height,
-                                            ClutterUnit  *natural_height)
+                                            gfloat        for_width,
+                                            gfloat       *min_height,
+                                            gfloat       *natural_height)
 {
   ClutterCairoTexturePrivate *priv = CLUTTER_CAIRO_TEXTURE (actor)->priv;
 
@@ -344,7 +359,7 @@ clutter_cairo_texture_get_preferred_height (ClutterActor *actor,
     *min_height = 0;
 
   if (natural_height)
-    *natural_height = CLUTTER_UNITS_FROM_DEVICE (priv->height);
+    *natural_height = (gfloat) priv->height;
 }
 
 static void
@@ -352,6 +367,7 @@ clutter_cairo_texture_class_init (ClutterCairoTextureClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   ClutterActorClass *actor_class = CLUTTER_ACTOR_CLASS (klass);
+  GParamSpec *pspec;
 
   gobject_class->finalize     = clutter_cairo_texture_finalize;
   gobject_class->set_property = clutter_cairo_texture_set_property;
@@ -373,14 +389,15 @@ clutter_cairo_texture_class_init (ClutterCairoTextureClass *klass)
    *
    * Since: 1.0
    */
+  pspec = g_param_spec_uint ("surface-width",
+                             P_("Surface Width"),
+                             P_("The width of the Cairo surface"),
+                             0, G_MAXUINT,
+                             0,
+                             CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class,
                                    PROP_SURFACE_WIDTH,
-                                   g_param_spec_uint ("surface-width",
-                                                      "Surface-Width",
-                                                      "Surface Width",
-                                                      0, G_MAXUINT,
-                                                      0,
-                                                      CLUTTER_PARAM_READWRITE));
+                                   pspec);
   /**
    * ClutterCairoTexture:surface-height:
    *
@@ -389,14 +406,15 @@ clutter_cairo_texture_class_init (ClutterCairoTextureClass *klass)
    *
    * Since: 1.0
    */
+  pspec = g_param_spec_uint ("surface-height",
+                             P_("Surface Height"),
+                             P_("The height of the Cairo surface"),
+                             0, G_MAXUINT,
+                             0,
+                             CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class,
                                    PROP_SURFACE_HEIGHT,
-                                   g_param_spec_uint ("surface-height",
-                                                      "Surface-Height",
-                                                      "Surface Height",
-                                                      0, G_MAXUINT,
-                                                      0,
-                                                      CLUTTER_PARAM_READWRITE));
+                                   pspec);
 }
 
 static void
@@ -412,6 +430,14 @@ clutter_cairo_texture_init (ClutterCairoTexture *self)
    * match that format
    */
   priv->format = CAIRO_FORMAT_ARGB32;
+
+  /* the Cairo surface is responsible for driving the size of
+   * the texture; if we let sync_size to its default of TRUE,
+   * the Texture will try to queue a relayout every time we
+   * change the size of the Cairo surface - which is not what
+   * we want
+   */
+  clutter_texture_set_sync_size (CLUTTER_TEXTURE (self), FALSE);
 }
 
 /**
@@ -440,87 +466,47 @@ static void
 clutter_cairo_texture_context_destroy (void *data)
 {
   ClutterCairoTextureContext *ctxt = data;
-  ClutterCairoTexture        *cairo = ctxt->cairo;
-  ClutterCairoTexturePrivate *priv;
-
-  gint    cairo_width, cairo_height, cairo_rowstride;
-  gint    surface_width, surface_height;
-  guchar *pixbuf_data, *dst, *cairo_data;
-  guint  *src, pixbuf_rowstride;
-  gint    x, y;
-
-  priv = CLUTTER_CAIRO_TEXTURE_GET_PRIVATE (cairo);
+  ClutterCairoTexture *cairo = ctxt->cairo;
+  ClutterCairoTexturePrivate *priv = cairo->priv;
+  guchar *cairo_data;
+  gint cairo_width, cairo_height;
+  gint surface_width, surface_height;
+  CoglHandle cogl_texture;
 
   if (!priv->cr_surface)
     return;
 
-  surface_width = cairo_image_surface_get_width (priv->cr_surface);
+  surface_width  = cairo_image_surface_get_width (priv->cr_surface);
   surface_height = cairo_image_surface_get_height (priv->cr_surface);
 
-  cairo_width = MIN (ctxt->rect.width, surface_width);
+  cairo_width  = MIN (ctxt->rect.width, surface_width);
   cairo_height = MIN (ctxt->rect.height, surface_height);
 
-  if (!cairo_width || !cairo_height)
+  cogl_texture = clutter_texture_get_cogl_texture (CLUTTER_TEXTURE (cairo));
+
+  if (!cairo_width || !cairo_height || cogl_texture == COGL_INVALID_HANDLE)
     {
       g_free (ctxt);
+
       return;
     }
 
-  cairo_rowstride  = priv->rowstride;
-  cairo_data       = priv->cr_surface_data;
-  pixbuf_data      = g_malloc (cairo_width * cairo_height * 4);
-  pixbuf_rowstride = cairo_width * 4;
+  cairo_data = (priv->cr_surface_data
+             + (ctxt->rect.y * priv->rowstride)
+             + (ctxt->rect.x * 4));
 
-  /* BAH BAH BAH ! un-pre-multiply alpha...
-   *
-   * FIXME: Need to figure out if GL has a premult texture
-   *        format, or we need to change the order of the
-   *        paint sequence in Clutter. or go back to battling
-   *        glitz (ugh).
-   *
-   * in theory, this could be moved to a shader, but apparently
-   * the performance gain is not really worth it.
-   */
-  for (y = 0; y < cairo_height; y++)
-    {
-      src = (unsigned int *) (cairo_data
-          + ((y + ctxt->rect.y) * cairo_rowstride)
-          + (ctxt->rect.x * 4));
-      dst = pixbuf_data + y * pixbuf_rowstride;
+  cogl_texture_set_region (cogl_texture,
+                           0, 0,
+                           ctxt->rect.x, ctxt->rect.y,
+                           cairo_width, cairo_height,
+                           cairo_width, cairo_height,
+                           CLUTTER_CAIRO_TEXTURE_PIXEL_FORMAT,
+                           priv->rowstride,
+                           cairo_data);
 
-      for (x = 0; x < cairo_width; x++)
-        {
-          guchar alpha = (*src >> 24) & 0xff;
-
-          if (alpha == 0)
-            dst[0] = dst[1] = dst[2] = dst[3] = alpha;
-          else
-            {
-              dst[0] = (((*src >> 16) & 0xff) * 255 ) / alpha;
-              dst[1] = (((*src >>  8) & 0xff) * 255 ) / alpha;
-              dst[2] = (((*src >>  0) & 0xff) * 255 ) / alpha;
-              dst[3] = alpha;
-            }
-
-          dst += 4;
-          src++;
-        }
-    }
-
-  clutter_texture_set_area_from_rgb_data (CLUTTER_TEXTURE (cairo),
-					  pixbuf_data,
-					  TRUE,
-					  ctxt->rect.x,
-					  ctxt->rect.y,
-					  cairo_width, cairo_height,
-					  pixbuf_rowstride,
-					  4, 0, NULL);
-
-  g_free (pixbuf_data);
   g_free (ctxt);
 
-  if (CLUTTER_ACTOR_IS_VISIBLE (cairo))
-    clutter_actor_queue_redraw (CLUTTER_ACTOR (cairo));
+  clutter_actor_queue_redraw (CLUTTER_ACTOR (cairo));
 }
 
 static void
@@ -760,3 +746,28 @@ clutter_cairo_texture_get_surface_size (ClutterCairoTexture *self,
   if (height)
     *height = self->priv->height;
 }
+
+/**
+ * clutter_cairo_texture_clear:
+ * @self: a #ClutterCairoTexture
+ *
+ * Clears @self's internal drawing surface, so that the next upload
+ * will replace the previous contents of the #ClutterCairoTexture
+ * rather than adding to it.
+ *
+ * Since: 1.0
+ */
+void
+clutter_cairo_texture_clear (ClutterCairoTexture *self)
+{
+  ClutterCairoTexturePrivate *priv;
+
+  g_return_if_fail (CLUTTER_IS_CAIRO_TEXTURE (self));
+
+  priv = self->priv;
+
+  if (!priv->cr_surface_data)
+    return;
+
+  memset (priv->cr_surface_data, 0, priv->height * priv->rowstride);
+}
