@@ -29,6 +29,7 @@
 #include "config.h"
 #endif
 
+#include "cogl-debug.h"
 #include "cogl-material-private.h"
 
 #ifdef COGL_MATERIAL_BACKEND_ARBFP
@@ -68,6 +69,11 @@
 #define glUseProgram ctx->drv.pf_glUseProgram
 #endif
 
+/* This might not be defined on GLES */
+#ifndef GL_TEXTURE_3D
+#define GL_TEXTURE_3D                           0x806F
+#endif
+
 typedef struct _CoglMaterialBackendARBfpPrivate
 {
   CoglMaterial *authority_cache;
@@ -415,6 +421,8 @@ gl_target_to_arbfp_string (GLenum gl_target)
   else if (gl_target == GL_TEXTURE_RECTANGLE_ARB)
     return "RECT";
 #endif
+  else if (gl_target == GL_TEXTURE_3D)
+    return "3D";
   else
     return "2D";
 }
@@ -518,18 +526,25 @@ setup_arg (CoglMaterial *material,
         CoglMaterialLayer *authority =
           _cogl_material_layer_get_authority (layer, state);
         CoglMaterialLayerBigState *big_state = authority->big_state;
+        char buf[4][G_ASCII_DTOSTR_BUF_SIZE];
+        int i;
 
         arg->type = COGL_MATERIAL_BACKEND_ARBFP_ARG_TYPE_CONSTANT;
         arg->name = "constant%d";
         arg->constant_id = priv->next_constant_id++;
+
+        for (i = 0; i < 4; i++)
+          g_ascii_dtostr (buf[i], G_ASCII_DTOSTR_BUF_SIZE,
+                          big_state->texture_combine_constant[i]);
+
         g_string_append_printf (priv->source,
                                 "PARAM constant%d = "
-                                "  {%f, %f, %f, %f};\n",
+                                "  {%s, %s, %s, %s};\n",
                                 arg->constant_id,
-                                big_state->texture_combine_constant[0],
-                                big_state->texture_combine_constant[1],
-                                big_state->texture_combine_constant[2],
-                                big_state->texture_combine_constant[3]);
+                                buf[0],
+                                buf[1],
+                                buf[2],
+                                buf[3]);
         break;
       }
     case GL_PRIMARY_COLOR:
