@@ -32,114 +32,11 @@
 
 #include "cogl-material.h"
 #include "cogl-matrix.h"
-#include "cogl-matrix-stack.h"
 #include "cogl-handle.h"
+#include "cogl-profile.h"
 
 #include <glib.h>
 
-/*
- * cogl-material.c owns the GPU's texture unit state so we have some
- * private structures for describing the current state of a texture
- * unit that we track in a per context array (ctx->texture_units) that
- * grows according to the largest texture unit used so far...
- *
- * Roughly speaking the members in this structure are of two kinds:
- * either they are a low level reflection of the state we send to
- * OpenGL or they are for high level meta data assoicated with the
- * texture unit when flushing CoglMaterialLayers that is typically
- * used to optimize subsequent re-flushing of the same layer.
- *
- * The low level members are at the top, and the high level members
- * start with the .layer member.
- */
-typedef struct _CoglTextureUnit
-{
-  /* The base 0 texture unit index which can be used with
-   * glActiveTexture () */
-  int                index;
-
-  /* Whether or not the corresponding gl_target has been glEnabled */
-  gboolean           enabled;
-
-  /* The GL target currently glEnabled or the target last enabled
-   * if .enabled == FALSE */
-  GLenum             current_gl_target;
-
-  /* The raw GL texture object name for which we called glBindTexture when
-   * we flushed the last layer. (NB: The CoglTexture associated
-   * with a layer may represent more than one GL texture) */
-  GLuint             gl_texture;
-
-  /* Foreign textures are those not created or deleted by Cogl. If we ever
-   * call glBindTexture for a foreign texture then the next time we are
-   * asked to glBindTexture we can't try and optimize a redundant state
-   * change because we don't know if the original texture name was deleted
-   * and now we are being asked to bind a recycled name. */
-  gboolean           is_foreign;
-
-  /* We have many components in Cogl that need to temporarily bind arbitrary
-   * textures e.g. to query texture object parameters and since we don't
-   * want that to result in too much redundant reflushing of layer state
-   * when all that's needed is to re-bind the layer's gl_texture we use this
-   * to track when the unit->gl_texture state is out of sync with the GL
-   * texture object really bound too (GL_TEXTURE0+unit->index).
-   *
-   * XXX: as a further optimization cogl-material.c uses a convention
-   * of always using texture unit 1 for these transient bindings so we
-   * can assume this is only ever TRUE for unit 1.
-   */
-  gboolean           dirty_gl_texture;
-
-  /* A matrix stack giving us the means to associate a texture
-   * transform matrix with the texture unit. */
-  CoglMatrixStack   *matrix_stack;
-
-  /*
-   * Higher level layer state associated with the unit...
-   */
-
-  /* The CoglMaterialLayer whos state was flushed to update this
-   * texture unit last.
-   *
-   * This will be set to NULL if the layer is modified or freed which
-   * means when we come to flush a layer; if this pointer is still
-   * valid and == to the layer being flushed we don't need to update
-   * any texture unit state. */
-  CoglMaterialLayer *layer;
-
-  /* To help minimize the state changes required we track the
-   * difference flags associated with the layer whos state was last
-   * flushed to update this texture unit.
-   *
-   * Note: we track this explicitly because .layer may get invalidated
-   * if that layer is modified or deleted. Even if the layer is
-   * invalidated though these flags can be used to optimize the state
-   * flush of the next layer
-   */
-  unsigned long      layer_changes_since_flush;
-
-  /* Whenever a CoglTexture's internal GL texture storage changes
-   * cogl-material.c is notified with a call to
-   * _cogl_material_texture_storage_change_notify which inturn sets
-   * this to TRUE for each texture unit that it is currently bound
-   * too. When we later come to flush some material state then we will
-   * always check this to potentially force an update of the texture
-   * state even if the material hasn't changed. */
-  gboolean           texture_storage_changed;
-
-} CoglTextureUnit;
-
-CoglTextureUnit *
-_cogl_get_texture_unit (int index_);
-
-void
-_cogl_destroy_texture_units (void);
-
-void
-_cogl_bind_gl_texture_transient (GLenum gl_target,
-                                 GLuint gl_texture,
-                                 gboolean is_foreign);
-
 #if defined (HAVE_COGL_GL)
 
 /* NB: material->backend is currently a 3bit unsigned int bitfield */
@@ -337,7 +234,7 @@ struct _CoglMaterialLayer
 
   CoglMaterialWrapMode       wrap_mode_s;
   CoglMaterialWrapMode       wrap_mode_t;
-  CoglMaterialWrapMode       wrap_mode_r;
+  CoglMaterialWrapMode       wrap_mode_p;
 
   /* Infrequent differences aren't currently tracked in
    * a separate, dynamically allocated structure as they are
@@ -655,6 +552,9 @@ typedef enum
   COGL_MATERIAL_PROGRAM_TYPE_FIXED
 } CoglMaterialProgramType;
 
+extern const CoglMaterialBackend *
+_cogl_material_backends[COGL_MATERIAL_N_BACKENDS];
+
 void
 _cogl_material_init_default_material (void);
 
@@ -756,7 +656,7 @@ typedef struct _CoglMaterialWrapModeOverrides
   {
     CoglMaterialWrapModeOverride s;
     CoglMaterialWrapModeOverride t;
-    CoglMaterialWrapModeOverride r;
+    CoglMaterialWrapModeOverride p;
   } values[COGL_MATERIAL_MAX_LAYERS];
 } CoglMaterialWrapModeOverrides;
 
@@ -775,12 +675,6 @@ typedef struct _CoglMaterialFlushOptions
 } CoglMaterialFlushOptions;
 
 
-void
-_cogl_set_active_texture_unit (int unit_index);
-
-void
-_cogl_delete_gl_texture (GLuint gl_texture);
-
 int
 _cogl_get_max_texture_image_units (void);
 
@@ -791,6 +685,8 @@ _cogl_use_program (CoglHandle program_handle, CoglMaterialProgramType type);
 unsigned int
 _cogl_get_n_args_for_combine_func (GLint func);
 
+void
+_cogl_material_set_backend (CoglMaterial *material, int backend);
 
 CoglMaterial *
 _cogl_material_get_parent (CoglMaterial *material);
@@ -799,9 +695,9 @@ void
 _cogl_material_get_colorubv (CoglMaterial *material,
                              guint8       *color);
 
-void
-_cogl_material_flush_gl_state (CoglMaterial *material,
-                               gboolean skip_gl_state);
+unsigned long
+_cogl_material_compare_differences (CoglMaterial *material0,
+                                    CoglMaterial *material1);
 
 gboolean
 _cogl_material_equal (CoglMaterial *material0,
@@ -814,15 +710,16 @@ _cogl_material_journal_ref (CoglMaterial *material);
 void
 _cogl_material_journal_unref (CoglMaterial *material);
 
-/* TODO: These should be made public once we add support for 3D
-   textures in Cogl */
 void
-_cogl_material_set_layer_wrap_mode_r (CoglMaterial *material,
-                                      int layer_index,
-                                      CoglMaterialWrapMode mode);
+_cogl_material_layer_get_wrap_modes (CoglMaterialLayer *layer,
+                                     CoglMaterialWrapModeInternal *wrap_mode_s,
+                                     CoglMaterialWrapModeInternal *wrap_mode_t,
+                                     CoglMaterialWrapModeInternal *wrap_mode_r);
 
-CoglMaterialWrapMode
-_cogl_material_layer_get_wrap_mode_r (CoglMaterialLayer *layer);
+void
+_cogl_material_layer_get_filters (CoglMaterialLayer *layer,
+                                  CoglMaterialFilter *min_filter,
+                                  CoglMaterialFilter *mag_filter);
 
 void
 _cogl_material_set_user_program (CoglMaterial *material,
@@ -834,9 +731,6 @@ _cogl_material_texture_storage_change_notify (CoglHandle texture);
 void
 _cogl_material_apply_legacy_state (CoglMaterial *material);
 
-void
-_cogl_gl_use_program_wrapper (GLuint program);
-
 void
 _cogl_material_apply_overrides (CoglMaterial *material,
                                 CoglMaterialFlushOptions *options);
